@@ -8,7 +8,7 @@ use crate::{
     requests::{HasPayload, Output, Payload, Request, Requester},
     types::{
         BotCommand, ChatAction, ChatId, ChatPermissions, InlineQueryResult, InputFile, InputMedia,
-        InputSticker, LabeledPrice, PassportElementError, PollType, TargetMessage,
+        InputSticker, LabeledPrice, PassportElementError, TargetMessage,
     },
 };
 
@@ -34,7 +34,14 @@ impl<'a, E> ErasedRequester<'a, E> {
     }
 }
 
+impl<E> std::fmt::Debug for ErasedRequester<'_, E> {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        f.debug_struct("ErasedRequester").finish_non_exhaustive()
+    }
+}
+
 /// [`Request`] with erased type.
+#[must_use = "Requests are lazy and do nothing unless sent"]
 pub struct ErasedRequest<'a, T, E> {
     inner: Box<dyn ErasableRequest<'a, Payload = T, Err = E> + 'a>,
 }
@@ -159,7 +166,8 @@ where
         stop_message_live_location, stop_message_live_location_inline, send_venue,
         send_contact, send_poll, send_dice, send_chat_action, get_user_profile_photos,
         get_file, kick_chat_member, ban_chat_member, unban_chat_member, restrict_chat_member,
-        promote_chat_member, set_chat_administrator_custom_title, set_chat_permissions,
+        promote_chat_member, set_chat_administrator_custom_title,
+        ban_chat_sender_chat, unban_chat_sender_chat, set_chat_permissions,
         export_chat_invite_link, create_chat_invite_link, edit_chat_invite_link,
         revoke_chat_invite_link, set_chat_photo, delete_chat_photo, set_chat_title,
         set_chat_description, pin_chat_message, unpin_chat_message, unpin_all_chat_messages,
@@ -174,7 +182,7 @@ where
         set_sticker_set_thumb, send_invoice, answer_shipping_query,
         answer_pre_checkout_query, set_passport_data_errors, send_game,
         set_game_score, set_game_score_inline, get_game_high_scores,
-        get_updates_fault_tolerant => fwd_erased, fty
+        approve_chat_join_request, decline_chat_join_request => fwd_erased, fty
     }
 }
 
@@ -323,7 +331,6 @@ trait ErasableRequester<'a> {
         chat_id: ChatId,
         question: String,
         options: Vec<String>,
-        type_: PollType,
     ) -> ErasedRequest<'a, SendPoll, Self::Err>;
 
     fn send_dice(&self, chat_id: ChatId) -> ErasedRequest<'a, SendDice, Self::Err>;
@@ -379,6 +386,18 @@ trait ErasableRequester<'a> {
         custom_title: String,
     ) -> ErasedRequest<'a, SetChatAdministratorCustomTitle, Self::Err>;
 
+    fn ban_chat_sender_chat(
+        &self,
+        chat_id: ChatId,
+        sender_chat_id: i64,
+    ) -> ErasedRequest<'a, BanChatSenderChat, Self::Err>;
+
+    fn unban_chat_sender_chat(
+        &self,
+        chat_id: ChatId,
+        sender_chat_id: i64,
+    ) -> ErasedRequest<'a, UnbanChatSenderChat, Self::Err>;
+
     fn set_chat_permissions(
         &self,
         chat_id: ChatId,
@@ -407,6 +426,20 @@ trait ErasableRequester<'a> {
         invite_link: String,
     ) -> ErasedRequest<'a, RevokeChatInviteLink, Self::Err>;
 
+    /// For Telegram documentation see [`ApproveChatJoinRequest`].
+    fn approve_chat_join_request(
+        &self,
+        chat_id: ChatId,
+        user_id: i64,
+    ) -> ErasedRequest<'a, ApproveChatJoinRequest, Self::Err>;
+
+    /// For Telegram documentation see [`DeclineChatJoinRequest`].
+    fn decline_chat_join_request(
+        &self,
+        chat_id: ChatId,
+        user_id: i64,
+    ) -> ErasedRequest<'a, DeclineChatJoinRequest, Self::Err>;
+
     fn set_chat_photo(
         &self,
         chat_id: ChatId,
@@ -658,8 +691,6 @@ trait ErasableRequester<'a> {
         user_id: i64,
         target: TargetMessage,
     ) -> ErasedRequest<'a, GetGameHighScores, Self::Err>;
-
-    fn get_updates_fault_tolerant(&self) -> ErasedRequest<'a, GetUpdatesFaultTolerant, Self::Err>;
 }
 
 impl<'a, B> ErasableRequester<'a> for B
@@ -862,9 +893,8 @@ where
         chat_id: ChatId,
         question: String,
         options: Vec<String>,
-        type_: PollType,
     ) -> ErasedRequest<'a, SendPoll, Self::Err> {
-        Requester::send_poll(self, chat_id, question, options, type_).erase()
+        Requester::send_poll(self, chat_id, question, options).erase()
     }
 
     fn send_dice(&self, chat_id: ChatId) -> ErasedRequest<'a, SendDice, Self::Err> {
@@ -940,6 +970,22 @@ where
         Requester::set_chat_administrator_custom_title(self, chat_id, user_id, custom_title).erase()
     }
 
+    fn ban_chat_sender_chat(
+        &self,
+        chat_id: ChatId,
+        sender_chat_id: i64,
+    ) -> ErasedRequest<'a, BanChatSenderChat, Self::Err> {
+        Requester::ban_chat_sender_chat(self, chat_id, sender_chat_id).erase()
+    }
+
+    fn unban_chat_sender_chat(
+        &self,
+        chat_id: ChatId,
+        sender_chat_id: i64,
+    ) -> ErasedRequest<'a, UnbanChatSenderChat, Self::Err> {
+        Requester::unban_chat_sender_chat(self, chat_id, sender_chat_id).erase()
+    }
+
     fn set_chat_permissions(
         &self,
         chat_id: ChatId,
@@ -978,6 +1024,24 @@ where
         Requester::revoke_chat_invite_link(self, chat_id, invite_link).erase()
     }
 
+    /// For Telegram documentation see [`ApproveChatJoinRequest`].
+    fn approve_chat_join_request(
+        &self,
+        chat_id: ChatId,
+        user_id: i64,
+    ) -> ErasedRequest<'a, ApproveChatJoinRequest, Self::Err> {
+        Requester::approve_chat_join_request(self, chat_id, user_id).erase()
+    }
+
+    /// For Telegram documentation see [`DeclineChatJoinRequest`].
+    fn decline_chat_join_request(
+        &self,
+        chat_id: ChatId,
+        user_id: i64,
+    ) -> ErasedRequest<'a, DeclineChatJoinRequest, Self::Err> {
+        Requester::decline_chat_join_request(self, chat_id, user_id).erase()
+    }
+
     fn set_chat_photo(
         &self,
         chat_id: ChatId,
@@ -1334,8 +1398,4 @@ where
     ) -> ErasedRequest<'a, GetGameHighScores, Self::Err> {
         Requester::get_game_high_scores(self, user_id, target).erase()
     }
-
-    fn get_updates_fault_tolerant(&self) -> ErasedRequest<'a, GetUpdatesFaultTolerant, Self::Err> {
-        Requester::get_updates_fault_tolerant(self).erase()
-    }
 }
