@@ -270,13 +270,7 @@ impl Requester for Bot {
 
     type SendPoll = JsonRequest<payloads::SendPoll>;
 
-    fn send_poll<C, Q, O>(
-        &self,
-        chat_id: C,
-        question: Q,
-        options: O,
-        type_: crate::types::PollType,
-    ) -> Self::SendPoll
+    fn send_poll<C, Q, O>(&self, chat_id: C, question: Q, options: O) -> Self::SendPoll
     where
         C: Into<ChatId>,
         Q: Into<String>,
@@ -284,7 +278,7 @@ impl Requester for Bot {
     {
         Self::SendPoll::new(
             self.clone(),
-            payloads::SendPoll::new(chat_id, question, options, type_),
+            payloads::SendPoll::new(chat_id, question, options),
         )
     }
 
@@ -405,6 +399,34 @@ impl Requester for Bot {
         )
     }
 
+    type BanChatSenderChat = JsonRequest<payloads::BanChatSenderChat>;
+
+    fn ban_chat_sender_chat<C>(&self, chat_id: C, sender_chat_id: i64) -> Self::BanChatSenderChat
+    where
+        C: Into<ChatId>,
+    {
+        Self::BanChatSenderChat::new(
+            self.clone(),
+            payloads::BanChatSenderChat::new(chat_id, sender_chat_id),
+        )
+    }
+
+    type UnbanChatSenderChat = JsonRequest<payloads::UnbanChatSenderChat>;
+
+    fn unban_chat_sender_chat<C>(
+        &self,
+        chat_id: C,
+        sender_chat_id: i64,
+    ) -> Self::UnbanChatSenderChat
+    where
+        C: Into<ChatId>,
+    {
+        Self::UnbanChatSenderChat::new(
+            self.clone(),
+            payloads::UnbanChatSenderChat::new(chat_id, sender_chat_id),
+        )
+    }
+
     type SetChatPermissions = JsonRequest<payloads::SetChatPermissions>;
 
     fn set_chat_permissions<C>(
@@ -469,6 +491,30 @@ impl Requester for Bot {
         )
     }
 
+    type ApproveChatJoinRequest = JsonRequest<payloads::ApproveChatJoinRequest>;
+
+    fn approve_chat_join_request<C>(&self, chat_id: C, user_id: i64) -> Self::ApproveChatJoinRequest
+    where
+        C: Into<ChatId>,
+    {
+        Self::ApproveChatJoinRequest::new(
+            self.clone(),
+            payloads::ApproveChatJoinRequest::new(chat_id, user_id),
+        )
+    }
+
+    type DeclineChatJoinRequest = JsonRequest<payloads::DeclineChatJoinRequest>;
+
+    fn decline_chat_join_request<C>(&self, chat_id: C, user_id: i64) -> Self::DeclineChatJoinRequest
+    where
+        C: Into<ChatId>,
+    {
+        Self::DeclineChatJoinRequest::new(
+            self.clone(),
+            payloads::DeclineChatJoinRequest::new(chat_id, user_id),
+        )
+    }
+
     type SetChatPhoto = MultipartRequest<payloads::SetChatPhoto>;
 
     fn set_chat_photo<C>(&self, chat_id: C, photo: InputFile) -> Self::SetChatPhoto
@@ -1060,13 +1106,4 @@ impl Requester for Bot {
     {
         Self::UnpinAllChatMessages::new(self.clone(), payloads::UnpinAllChatMessages::new(chat_id))
     }
-
-    type GetUpdatesFaultTolerant = JsonRequest<payloads::GetUpdatesFaultTolerant>;
-
-    fn get_updates_fault_tolerant(&self) -> Self::GetUpdatesFaultTolerant {
-        Self::GetUpdatesFaultTolerant::new(
-            self.clone(),
-            payloads::GetUpdatesFaultTolerant(payloads::GetUpdates::new()),
-        )
-    }
 }
