@@ -51,7 +51,7 @@
 //! - `erased` — enables [`ErasedRequester`] bot adaptor
 //! - `throttle` — enables [`Throttle`] bot adaptor
 //! - `cache_me` — enables [`CacheMe`] bot adaptor
-//! - `full` — enables all features except `nigthly`
+//! - `full` — enables all features except `nigthly` and tls-related
 //! - `nightly` — enables nigthly-only features, currently:
 //!   - Removes some future boxing using `#![feature(type_alias_impl_trait)]`
 //!   - Used to built docs (`#![feature(doc_cfg, doc_notable_trait)]`)
@@ -74,21 +74,22 @@
 //
 // To properly build docs of this crate run
 // ```console
-// $ RUSTDOCFLAGS="--cfg docsrs -Znormalize-docs" cargo doc --open --all-features
+// $ cargo docs
 // ```
+// (docs alias is defined in `.cargo/config.toml`)
 //
 // `dep_docsrs` is used for the same purpose, but when `teloxide-core` is built as a dependency
 // (see: `teloxide`). We can't use `docsrs` as it breaks tokio compilation in this case.
 #![cfg_attr(
     all(any(docsrs, dep_docsrs), feature = "nightly"),
-    feature(doc_cfg, doc_notable_trait)
+    feature(doc_cfg, doc_auto_cfg, doc_notable_trait)
 )]
 #![cfg_attr(feature = "nightly", feature(type_alias_impl_trait))]
 #![cfg_attr(all(feature = "full", docsrs), deny(rustdoc::broken_intra_doc_links))]
 //#![deny(missing_docs)]
-
-// https://github.com/rust-lang/rust-clippy/issues/7422
-#![allow(clippy::nonstandard_macro_braces)]
+#![warn(clippy::print_stdout, clippy::dbg_macro)]
+// Unless this becomes machine applicable, I'm not adding 334 #[must_use]s (waffle)
+#![allow(clippy::return_self_not_must_use)]
 
 // The internal helper macros.
 #[macro_use]
