@@ -1,3 +1,4 @@
+use chrono::{DateTime, Utc};
 use serde::{Deserialize, Serialize};
 
 use crate::types::User;
@@ -9,14 +10,22 @@ pub struct ChatInviteLink {
     pub invite_link: String,
     /// Creator of the link
     pub creator: User,
+    /// `true`, if users joining the chat via the link need to be approved by
+    /// chat administrators
+    pub creates_join_request: bool,
     /// `true`, if the link is primary
     pub is_primary: bool,
     /// `true`, if the link is revoked
     pub is_revoked: bool,
-    /// Point in time (Unix timestamp) when the link will expire or has been
+    /// Invite link name
+    pub name: Option<String>,
+    /// Point in time when the link will expire or has been
     /// expired
-    pub expire_date: Option<i64>,
+    #[serde(default, with = "crate::types::serde_opt_date_from_unix_timestamp")]
+    pub expire_date: Option<DateTime<Utc>>,
     /// Maximum number of users that can be members of the chat simultaneously
     /// after joining the chat via this invite link; 1-99999
     pub member_limit: Option<u32>,
+    /// Number of pending join requests created using this link
+    pub pending_join_request_count: Option<u32>,
 }
