@@ -1,5 +1,6 @@
 #![allow(clippy::large_enum_variant)]
 
+use chrono::{DateTime, Utc};
 use serde::{Deserialize, Serialize};
 
 use crate::types::{
@@ -19,7 +20,8 @@ pub struct Message {
     pub id: i32,
 
     /// Date the message was sent in Unix time.
-    pub date: i32,
+    #[serde(with = "crate::types::serde_date_from_unix_timestamp")]
+    pub date: DateTime<Utc>,
 
     /// Conversation the message belongs to.
     pub chat: Chat,
@@ -44,7 +46,6 @@ pub enum MessageKind {
     SupergroupChatCreated(MessageSupergroupChatCreated),
     ChannelChatCreated(MessageChannelChatCreated),
     MessageAutoDeleteTimerChanged(MessageMessageAutoDeleteTimerChanged),
-    Migrate(MessageMigrate),
     Pinned(MessagePinned),
     Invoice(MessageInvoice),
     SuccessfulPayment(MessageSuccessfulPayment),
@@ -74,11 +75,18 @@ pub struct MessageCommon {
     /// title of an anonymous group administrator.
     pub author_signature: Option<String>,
 
+    /// For forwarded messages, information about the forward
     #[serde(flatten)]
-    pub forward_kind: ForwardKind,
+    pub forward: Option<Forward>,
+
+    /// For replies, the original message. Note that the Message object in this
+    /// field will not contain further `reply_to_message` fields even if it
+    /// itself is a reply.
+    pub reply_to_message: Option<Box<Message>>,
 
     /// Date the message was last edited in Unix time.
-    pub edit_date: Option<i32>,
+    #[serde(default, with = "crate::types::serde_opt_date_from_unix_timestamp")]
+    pub edit_date: Option<DateTime<Utc>>,
 
     #[serde(flatten)]
     pub media_kind: MediaKind,
@@ -86,6 +94,15 @@ pub struct MessageCommon {
     /// Inline keyboard attached to the message. `login_url` buttons are
     /// represented as ordinary `url` buttons.
     pub reply_markup: Option<InlineKeyboardMarkup>,
+
+    /// `true`, if the message is a channel post that was automatically
+    /// forwarded to the connected discussion group.
+    #[serde(default)]
+    pub is_automatic_forward: bool,
+
+    /// `true`, if the message can't be forwarded.
+    #[serde(default)]
+    pub has_protected_content: bool,
 }
 
 #[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
@@ -153,23 +170,32 @@ pub struct MessageMessageAutoDeleteTimerChanged {
     pub message_auto_delete_timer_changed: MessageAutoDeleteTimerChanged,
 }
 
-#[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
-pub struct MessageMigrate {
+/// Represents group migration to a supergroup or a supergroup migration from a
+/// group.
+///
+/// Note that bot receives **both** updates. For example: a group with id `0`
+/// migrates to a supergroup with id `1` bots in that group will receive 2
+/// updates:
+/// - `message.chat.id = 0`, `message.chat_migration() = ChatMigration::To {
+///   chat_id: 1 }`
+/// - `message.chat.id = 1`, `message.chat_migration() = ChatMigration::From {
+///   chat_id: 0 }`
+#[derive(Copy, Clone, Debug, PartialEq, Serialize, Deserialize)]
+#[serde(untagged)]
+pub enum ChatMigration {
     /// The group has been migrated to a supergroup with the specified
-    /// identifier. This number may be greater than 32 bits and some
-    /// programming languages may have difficulty/silent defects in
-    /// interpreting it. But it is smaller than 52 bits, so a signed 64 bit
-    /// integer or double-precision float type are safe for storing this
-    /// identifier.
-    pub migrate_to_chat_id: i64,
+    /// identifier `chat_id`.
+    To {
+        #[serde(rename = "migrate_to_chat_id")]
+        chat_id: i64,
+    },
 
     /// The supergroup has been migrated from a group with the specified
-    /// identifier. This number may be greater than 32 bits and some
-    /// programming languages may have difficulty/silent defects in
-    /// interpreting it. But it is smaller than 52 bits, so a signed 64 bit
-    /// integer or double-precision float type are safe for storing this
-    /// identifier.
-    pub migrate_from_chat_id: i64,
+    /// identifier `chat_id`.
+    From {
+        #[serde(rename = "migrate_from_chat_id")]
+        chat_id: i64,
+    },
 }
 
 #[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
@@ -215,59 +241,63 @@ pub struct MessagePassportData {
     pub passport_data: PassportData,
 }
 
-#[derive(Clone, Debug, Eq, Hash, PartialEq, Serialize, Deserialize)]
+/// Information about forwarded message.
+#[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
+pub struct Forward {
+    /// Date the original message was sent in Unix time.
+    #[serde(rename = "forward_date")]
+    #[serde(with = "crate::types::serde_date_from_unix_timestamp")]
+    pub date: DateTime<Utc>,
+
+    /// The entity that sent the original message.
+    #[serde(flatten)]
+    pub from: ForwardedFrom,
+
+    /// For messages forwarded from channels, signature of the post author if
+    /// present. For messages forwarded from anonymous admins, authors title, if
+    /// present.
+    #[serde(rename = "forward_signature")]
+    pub signature: Option<String>,
+
+    /// For messages forwarded from channels, identifier of the original message
+    /// in the channel
+    #[serde(rename = "forward_from_message_id")]
+    pub message_id: Option<i32>,
+}
+
+/// The entity that sent the original message that later was forwarded.
+#[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
 pub enum ForwardedFrom {
+    /// The message was sent by a user.
     #[serde(rename = "forward_from")]
     User(User),
+    /// The message was sent by an anonymous user on behalf of a group or
+    /// channel.
+    #[serde(rename = "forward_from_chat")]
+    Chat(Chat),
+    /// The message was sent by a user who disallow adding a link to their
+    /// account in forwarded messages.
     #[serde(rename = "forward_sender_name")]
     SenderName(String),
 }
 
-#[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
-#[serde(untagged)]
-pub enum ForwardKind {
-    Channel(ForwardChannel),
-    NonChannel(ForwardNonChannel),
-    Origin(ForwardOrigin),
-}
-
-#[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
-pub struct ForwardChannel {
-    #[serde(rename = "forward_date")]
-    pub date: i32,
-
-    #[serde(rename = "forward_from_chat")]
-    pub chat: Chat,
-
-    #[serde(rename = "forward_from_message_id")]
-    pub message_id: i32,
-
-    #[serde(rename = "forward_signature")]
-    pub signature: Option<String>,
-}
-
-#[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
-pub struct ForwardNonChannel {
-    #[serde(rename = "forward_date")]
-    pub date: i32,
-
-    #[serde(flatten)]
-    pub from: ForwardedFrom,
-}
-
-#[derive(Clone, Debug, Default, PartialEq, Serialize, Deserialize)]
-pub struct ForwardOrigin {
-    pub reply_to_message: Option<Box<Message>>,
-}
-
 #[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
 #[serde(untagged)]
 pub enum MediaKind {
+    // Note:
+    // - `Venue` must be in front of `Location`
+    // - `Animation` must be in front of `Document`
+    //
+    // This is needed so serde doesn't parse `Venue` as `Location` or `Animation` as `Document`
+    // (for backward compatability telegram duplicates some fields)
+    //
+    // See <https://github.com/teloxide/teloxide/issues/481>
     Animation(MediaAnimation),
     Audio(MediaAudio),
     Contact(MediaContact),
     Document(MediaDocument),
     Game(MediaGame),
+    Venue(MediaVenue),
     Location(MediaLocation),
     Photo(MediaPhoto),
     Poll(MediaPoll),
@@ -276,7 +306,7 @@ pub enum MediaKind {
     Video(MediaVideo),
     VideoNote(MediaVideoNote),
     Voice(MediaVoice),
-    Venue(MediaVenue),
+    Migration(ChatMigration),
 }
 
 #[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
@@ -286,11 +316,6 @@ pub struct MediaAnimation {
     /// will also be set.
     pub animation: Animation,
 
-    #[doc(hidden)]
-    /// "For backward compatibility" (c) Telegram Docs.
-    #[serde(skip)]
-    pub document: (),
-
     /// Caption for the animation, 0-1024 characters.
     pub caption: Option<String>,
 
@@ -298,6 +323,7 @@ pub struct MediaAnimation {
     /// bot commands, etc. that appear in the caption.
     #[serde(default = "Vec::new")]
     pub caption_entities: Vec<MessageEntity>,
+    // Note: for backward compatibility telegram also sends `document` field, but we ignore it
 }
 
 #[serde_with_macros::skip_serializing_none]
@@ -313,6 +339,10 @@ pub struct MediaAudio {
     /// bot commands, etc. that appear in the caption.
     #[serde(default = "Vec::new")]
     pub caption_entities: Vec<MessageEntity>,
+
+    /// The unique identifier of a media message group this message belongs
+    /// to.
+    pub media_group_id: Option<String>,
 }
 
 #[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
@@ -332,8 +362,12 @@ pub struct MediaDocument {
 
     /// For messages with a caption, special entities like usernames, URLs,
     /// bot commands, etc. that appear in the caption.
-    #[serde(default = "Vec::new")]
+    #[serde(default)]
     pub caption_entities: Vec<MessageEntity>,
+
+    /// The unique identifier of a media message group this message belongs
+    /// to.
+    pub media_group_id: Option<String>,
 }
 
 #[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
@@ -440,6 +474,7 @@ pub struct MediaVoice {
 pub struct MediaVenue {
     /// Message is a venue, information about the venue.
     pub venue: Venue,
+    // Note: for backward compatibility telegram also sends `location` field, but we ignore it
 }
 
 #[derive(Clone, Debug, PartialEq, Serialize, Deserialize)]
@@ -480,20 +515,18 @@ pub struct MessageVoiceChatParticipantsInvited {
 }
 
 mod getters {
+    use chrono::{DateTime, Utc};
     use std::ops::Deref;
 
     use crate::types::{
-        self,
-        message::{ForwardKind::NonChannel, MessageKind::*},
-        Chat, ForwardChannel, ForwardKind, ForwardNonChannel, ForwardOrigin, ForwardedFrom,
-        MediaAnimation, MediaAudio, MediaContact, MediaDocument, MediaGame, MediaKind,
-        MediaLocation, MediaPhoto, MediaPoll, MediaSticker, MediaText, MediaVenue, MediaVideo,
-        MediaVideoNote, MediaVoice, Message, MessageChannelChatCreated, MessageCommon,
-        MessageConnectedWebsite, MessageDeleteChatPhoto, MessageDice, MessageEntity,
-        MessageGroupChatCreated, MessageInvoice, MessageLeftChatMember, MessageMigrate,
-        MessageNewChatMembers, MessageNewChatPhoto, MessageNewChatTitle, MessagePassportData,
-        MessagePinned, MessageProximityAlertTriggered, MessageSuccessfulPayment,
-        MessageSupergroupChatCreated, PhotoSize, True, User,
+        self, message::MessageKind::*, Chat, ChatMigration, Forward, ForwardedFrom, MediaAnimation,
+        MediaAudio, MediaContact, MediaDocument, MediaGame, MediaKind, MediaLocation, MediaPhoto,
+        MediaPoll, MediaSticker, MediaText, MediaVenue, MediaVideo, MediaVideoNote, MediaVoice,
+        Message, MessageChannelChatCreated, MessageCommon, MessageConnectedWebsite,
+        MessageDeleteChatPhoto, MessageDice, MessageEntity, MessageGroupChatCreated,
+        MessageInvoice, MessageLeftChatMember, MessageNewChatMembers, MessageNewChatPhoto,
+        MessageNewChatTitle, MessagePassportData, MessagePinned, MessageProximityAlertTriggered,
+        MessageSuccessfulPayment, MessageSupergroupChatCreated, PhotoSize, True, User,
     };
 
     /// Getters for [Message] fields from [telegram docs].
@@ -528,76 +561,52 @@ mod getters {
             self.chat.id
         }
 
-        /// NOTE: this is getter for both `forward_from` and
-        /// `forward_sender_name`
+        pub fn forward(&self) -> Option<&Forward> {
+            self.common().and_then(|m| m.forward.as_ref())
+        }
+
+        pub fn forward_date(&self) -> Option<DateTime<Utc>> {
+            self.forward().map(|f| f.date)
+        }
+
         pub fn forward_from(&self) -> Option<&ForwardedFrom> {
-            match &self.kind {
-                Common(MessageCommon {
-                    forward_kind: NonChannel(ForwardNonChannel { from, .. }),
-                    ..
-                }) => Some(from),
+            self.forward().map(|f| &f.from)
+        }
+
+        pub fn forward_from_user(&self) -> Option<&User> {
+            self.forward_from().and_then(|from| match from {
+                ForwardedFrom::User(user) => Some(user),
                 _ => None,
-            }
+            })
         }
 
         pub fn forward_from_chat(&self) -> Option<&Chat> {
-            match &self.kind {
-                Common(MessageCommon {
-                    forward_kind: ForwardKind::Channel(ForwardChannel { chat, .. }),
-                    ..
-                }) => Some(chat),
+            self.forward_from().and_then(|from| match from {
+                ForwardedFrom::Chat(chat) => Some(chat),
                 _ => None,
-            }
+            })
         }
 
-        pub fn forward_from_message_id(&self) -> Option<&i32> {
-            match &self.kind {
-                Common(MessageCommon {
-                    forward_kind: ForwardKind::Channel(ForwardChannel { message_id, .. }),
-                    ..
-                }) => Some(message_id),
+        pub fn forward_from_sender_name(&self) -> Option<&str> {
+            self.forward_from().and_then(|from| match from {
+                ForwardedFrom::SenderName(sender_name) => Some(&**sender_name),
                 _ => None,
-            }
+            })
+        }
+
+        pub fn forward_from_message_id(&self) -> Option<i32> {
+            self.forward().and_then(|f| f.message_id)
         }
 
         pub fn forward_signature(&self) -> Option<&str> {
-            match &self.kind {
-                Common(MessageCommon {
-                    forward_kind: ForwardKind::Channel(ForwardChannel { signature, .. }),
-                    ..
-                }) => signature.as_ref().map(Deref::deref),
-                _ => None,
-            }
-        }
-
-        pub fn forward_date(&self) -> Option<&i32> {
-            match &self.kind {
-                Common(MessageCommon {
-                    forward_kind: ForwardKind::Channel(ForwardChannel { date, .. }),
-                    ..
-                })
-                | Common(MessageCommon {
-                    forward_kind: ForwardKind::NonChannel(ForwardNonChannel { date, .. }),
-                    ..
-                }) => Some(date),
-                _ => None,
-            }
+            self.forward().and_then(|f| f.signature.as_deref())
         }
 
         pub fn reply_to_message(&self) -> Option<&Message> {
-            match &self.kind {
-                Common(MessageCommon {
-                    forward_kind:
-                        ForwardKind::Origin(ForwardOrigin {
-                            reply_to_message, ..
-                        }),
-                    ..
-                }) => reply_to_message.as_ref().map(Deref::deref),
-                _ => None,
-            }
+            self.common().and_then(|m| m.reply_to_message.as_deref())
         }
 
-        pub fn edit_date(&self) -> Option<&i32> {
+        pub fn edit_date(&self) -> Option<&DateTime<Utc>> {
             match &self.kind {
                 Common(MessageCommon { edit_date, .. }) => edit_date.as_ref(),
                 _ => None,
@@ -613,6 +622,14 @@ mod getters {
                 | Common(MessageCommon {
                     media_kind: MediaKind::Photo(MediaPhoto { media_group_id, .. }),
                     ..
+                })
+                | Common(MessageCommon {
+                    media_kind: MediaKind::Document(MediaDocument { media_group_id, .. }),
+                    ..
+                })
+                | Common(MessageCommon {
+                    media_kind: MediaKind::Audio(MediaAudio { media_group_id, .. }),
+                    ..
                 }) => media_group_id.as_ref().map(Deref::deref),
                 _ => None,
             }
@@ -903,21 +920,32 @@ mod getters {
             }
         }
 
+        pub fn chat_migration(&self) -> Option<ChatMigration> {
+            match &self.kind {
+                Common(MessageCommon {
+                    media_kind: MediaKind::Migration(chat_migration),
+                    ..
+                }) => Some(*chat_migration),
+                _ => None,
+            }
+        }
+
         pub fn migrate_to_chat_id(&self) -> Option<i64> {
             match &self.kind {
-                Migrate(MessageMigrate {
-                    migrate_to_chat_id, ..
-                }) => Some(*migrate_to_chat_id),
+                Common(MessageCommon {
+                    media_kind: MediaKind::Migration(ChatMigration::To { chat_id }),
+                    ..
+                }) => Some(*chat_id),
                 _ => None,
             }
         }
 
         pub fn migrate_from_chat_id(&self) -> Option<i64> {
             match &self.kind {
-                Migrate(MessageMigrate {
-                    migrate_from_chat_id,
+                Common(MessageCommon {
+                    media_kind: MediaKind::Migration(ChatMigration::From { chat_id }),
                     ..
-                }) => Some(*migrate_from_chat_id),
+                }) => Some(*chat_id),
                 _ => None,
             }
         }
@@ -983,13 +1011,41 @@ mod getters {
                 _ => None,
             }
         }
+
+        pub fn is_automatic_forward(&self) -> bool {
+            match &self.kind {
+                Common(MessageCommon {
+                    is_automatic_forward,
+                    ..
+                }) => *is_automatic_forward,
+                _ => false,
+            }
+        }
+
+        pub fn has_protected_content(&self) -> bool {
+            match &self.kind {
+                Common(MessageCommon {
+                    has_protected_content,
+                    ..
+                }) => *has_protected_content,
+                _ => false,
+            }
+        }
+
+        /// Common message (text, image, etc)
+        fn common(&self) -> Option<&MessageCommon> {
+            match &self.kind {
+                Common(message) => Some(message),
+                _ => None,
+            }
+        }
     }
 }
 
 impl Message {
     /// Produces a direct link to the message.
     ///
-    /// Note that for private groups the link will only be accesible for group
+    /// Note that for private groups the link will only be accessible for group
     /// members.
     ///
     /// Returns `None` for private chats (i.e.: DMs).
@@ -1000,17 +1056,21 @@ impl Message {
             // There are "tg://openmessage?user_id={0}&message_id={1}" links, which are
             // supposed to open any chat, including private messages, but they
             // are only supported by some telegram clients (e.g. Plus Messenger,
-            // Telegram for Androud 4.9+).
+            // Telegram for Android 4.9+).
             return None;
         }
 
         let url = match self.chat.username() {
             // If it's public group (i.e. not DM, not private group), we can produce
-            // "normal" t.me link (accesible to everyone).
+            // "normal" t.me link (accessible to everyone).
             Some(username) => format!("https://t.me/{0}/{1}/", username, self.id),
             // For private groups we produce "private" t.me/c links. These are only
-            // accesible to the group members.
-            None => format!("https://t.me/c/{0}/{1}/", self.chat.id, self.id),
+            // accessible to the group members.
+            None => format!(
+                "https://t.me/c/{0}/{1}/",
+                (-self.chat.id) - 1000000000000,
+                self.id
+            ),
         };
 
         // UNWRAP:
@@ -1162,6 +1222,7 @@ mod tests {
            "emoji": "😡",
            "set_name": "AdvenTimeAnim",
            "is_animated": true,
+           "is_video": false,
            "thumb": {
             "file_id": "AAQCAAMjAAOw0PgMaabKAcaXKCBLubkPAAQBAAdtAAPGKwACFgQ",
             "file_unique_id":"",
@@ -1174,8 +1235,7 @@ mod tests {
            "file_size": 16639
           }
          }"#;
-        let message = from_str::<Message>(json);
-        assert!(message.is_ok());
+        from_str::<Message>(json).unwrap();
     }
 
     #[test]
@@ -1225,4 +1285,175 @@ mod tests {
         let message = from_str::<Message>(json);
         assert!(message.is_ok());
     }
+
+    /// Regression test for <https://github.com/teloxide/teloxide/issues/419>
+    #[test]
+    fn issue_419() {
+        let json = r#"{
+            "message_id": 1,
+            "from": {
+                "id": 1087968824,
+                "is_bot": true,
+                "first_name": "Group",
+                "username": "GroupAnonymousBot"
+            },
+            "author_signature": "TITLE2",
+            "sender_chat": {
+                "id": -1001160242915,
+                "title": "a",
+                "type": "supergroup"
+            },
+            "chat": {
+                "id": -1001160242915,
+                "title": "a",
+                "type": "supergroup"
+            },
+            "date": 1640359576,
+            "forward_from_chat": {
+                "id": -1001160242915,
+                "title": "a",
+                "type": "supergroup"
+            },
+            "forward_signature": "TITLE",
+            "forward_date": 1640359544,
+            "text": "text"
+        }"#;
+
+        // Anonymous admin with title "TITLE2" forwards a message from anonymous
+        // admin with title "TITLE" with text "a", everything is happening in
+        // the same group.
+        let message: Message = serde_json::from_str(json).unwrap();
+
+        let group = Chat {
+            id: -1001160242915,
+            kind: ChatKind::Public(ChatPublic {
+                title: Some("a".to_owned()),
+                kind: PublicChatKind::Supergroup(PublicChatSupergroup {
+                    username: None,
+                    sticker_set_name: None,
+                    can_set_sticker_set: None,
+                    permissions: None,
+                    slow_mode_delay: None,
+                    linked_chat_id: None,
+                    location: None,
+                }),
+                description: None,
+                invite_link: None,
+                has_protected_content: None,
+            }),
+            message_auto_delete_time: None,
+            photo: None,
+            pinned_message: None,
+        };
+
+        assert!(message.from().unwrap().is_anonymous());
+        assert_eq!(message.author_signature().unwrap(), "TITLE2");
+        assert_eq!(message.sender_chat().unwrap(), &group);
+        assert_eq!(&message.chat, &group);
+        assert_eq!(message.forward_from_chat().unwrap(), &group);
+        assert_eq!(message.forward_signature().unwrap(), "TITLE");
+        assert!(message.forward_date().is_some());
+        assert_eq!(message.text().unwrap(), "text");
+    }
+
+    /// Regression test for <https://github.com/teloxide/teloxide/issues/427>
+    #[test]
+    fn issue_427() {
+        let old = -599075523;
+        let new = -1001555296434;
+
+        // Migration to a supergroup
+        let json = r#"{"chat":{"all_members_are_administrators":false,"id":-599075523,"title":"test","type":"group"},"date":1629404938,"from":{"first_name":"nullptr","id":729497414,"is_bot":false,"language_code":"en","username":"hex0x0000"},"message_id":16,"migrate_to_chat_id":-1001555296434}"#;
+        let message: Message = from_str(json).unwrap();
+
+        assert_eq!(message.chat.id, old);
+        assert_eq!(
+            message.chat_migration(),
+            Some(ChatMigration::To { chat_id: new })
+        );
+        assert_eq!(message.migrate_to_chat_id(), Some(new));
+
+        // The user who initialized the migration
+        assert!(message.from().is_some());
+
+        // Migration from a common group
+        let json = r#"{"chat":{"id":-1001555296434,"title":"test","type":"supergroup"},"date":1629404938,"from":{"first_name":"Group","id":1087968824,"is_bot":true,"username":"GroupAnonymousBot"},"message_id":1,"migrate_from_chat_id":-599075523,"sender_chat":{"id":-1001555296434,"title":"test","type":"supergroup"}}"#;
+        let message: Message = from_str(json).unwrap();
+
+        assert_eq!(message.chat.id, new);
+        assert_eq!(
+            message.chat_migration(),
+            Some(ChatMigration::From { chat_id: old })
+        );
+        assert_eq!(message.migrate_from_chat_id(), Some(old));
+
+        // Anonymous bot
+        assert!(message.from().is_some());
+
+        // The chat to which the group migrated
+        assert!(message.sender_chat().is_some());
+    }
+
+    /// Regression test for <https://github.com/teloxide/teloxide/issues/481>
+    #[test]
+    fn issue_481() {
+        let json = r#"
+{
+  "message_id": 0,
+  "date": 0,
+  "location": {
+   "latitude": 0.0,
+   "longitude": 0.0
+  },
+  "chat": {
+   "id": 0,
+   "first_name": "f",
+   "type": "private"
+  },
+  "venue": {
+   "location": {
+    "latitude": 0.0,
+    "longitude": 0.0
+   },
+   "title": "Title",
+   "address": "Address",
+   "foursquare_id": "some_foursquare_id"
+  }
+ }
+"#;
+        let message: Message = from_str(json).unwrap();
+        assert_eq!(
+            message.venue().unwrap(),
+            &Venue {
+                location: Location {
+                    longitude: 0.0,
+                    latitude: 0.0,
+                    horizontal_accuracy: None,
+                    live_period: None,
+                    heading: None,
+                    proximity_alert_radius: None
+                },
+                title: "Title".to_owned(),
+                address: "Address".to_owned(),
+                foursquare_id: Some("some_foursquare_id".to_owned()),
+                foursquare_type: None,
+                google_place_id: None,
+                google_place_type: None,
+            }
+        )
+    }
+
+    /// Regression test for <https://github.com/teloxide/teloxide/issues/475>
+    #[test]
+    fn issue_475() {
+        let json = r#"{"message_id":198295,"from":{"id":1087968824,"is_bot":true,"first_name":"Group","username":"GroupAnonymousBot"},"sender_chat":{"id":-1001331354980,"title":"C++ Together 2.0","username":"cpptogether","type":"supergroup"},"chat":{"id":-1001331354980,"title":"C++ Together 2.0","username":"cpptogether","type":"supergroup"},"date":1638236631,"voice_chat_started":{}}"#;
+
+        let message: Message = serde_json::from_str(json).unwrap();
+
+        assert!(matches!(message.kind, MessageKind::VoiceChatStarted { .. }));
+
+        // FIXME(waffle): it seems like we are losing `sender_chat` in some
+        // cases inclusing this
+        // assert!(message.sender_chat().is_some());
+    }
 }
